@@ -25,13 +25,15 @@ class AsyncFakeSocket(_fakesocket.FakeSocket):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.responses = asyncio.Queue()
+        self.responses = asyncio.Queue()  # type:ignore
 
     def _decode_error(self, error):
         parser = DefaultParser(1)
         return parser.parse_error(error.value)
 
-    def put_response(self, msg):
+    def put_response(self, msg) -> None:
+        if not self.responses:
+            return
         self.responses.put_nowait(msg)
 
     async def _async_blocking(self, timeout, func, event, callback):
@@ -78,14 +80,14 @@ class FakeReader:
         self._socket = socket
 
     async def read(self, _: int) -> bytes:
-        return await self._socket.responses.get()
+        return await self._socket.responses.get()  # type:ignore
 
 
 class FakeWriter:
     def __init__(self, socket: AsyncFakeSocket) -> None:
-        self._socket = socket
+        self._socket: Optional[AsyncFakeSocket] = socket
 
-    def close(self):
+    def close(self) -> None:
         self._socket = None
 
     async def wait_closed(self):
@@ -94,13 +96,14 @@ class FakeWriter:
     async def drain(self):
         pass
 
-    def writelines(self, data):
+    def writelines(self, data) -> None:
+        if self._socket is None:
+            return
         for chunk in data:
             self._socket.sendall(chunk)
 
 
 class FakeConnection(FakeBaseConnectionMixin, redis_async.Connection):
-
     async def _connect(self):
         if not self._server.connected:
             raise redis_async.ConnectionError(msgs.CONNECTION_ERROR_MSG)
@@ -116,14 +119,14 @@ class FakeConnection(FakeBaseConnectionMixin, redis_async.Connection):
         if not self.is_connected:
             await self.connect()
         if timeout == 0:
-            return not self._sock.responses.empty()
+            return self._sock is not None and not self._sock.responses.empty()
         # asyncio.Queue doesn't have a way to wait for the queue to be
         # non-empty without consuming an item, so kludge it with a sleep/poll
         # loop.
         loop = asyncio.get_event_loop()
         start = loop.time()
         while True:
-            if not self._sock.responses.empty():
+            if self._sock and not self._sock.responses.empty():
                 return True
             await asyncio.sleep(0.01)
             now = loop.time()
@@ -134,20 +137,24 @@ class FakeConnection(FakeBaseConnectionMixin, redis_async.Connection):
         if isinstance(response, list):
             return [self._decode(item) for item in response]
         elif isinstance(response, bytes):
-            return self.encoder.decode(response, )
+            return self.encoder.decode(
+                response,
+            )
         else:
             return response
 
     async def read_response(self, **kwargs):
+        if not self._sock:
+            raise redis_async.ConnectionError(msgs.CONNECTION_ERROR_MSG)
         if not self._server.connected:
             try:
                 response = self._sock.responses.get_nowait()
             except asyncio.QueueEmpty:
-                if kwargs.get('disconnect_on_error', True):
+                if kwargs.get("disconnect_on_error", True):
                     await self.disconnect()
                 raise redis_async.ConnectionError(msgs.CONNECTION_ERROR_MSG)
         else:
-            timeout = kwargs.pop('timeout', None)
+            timeout = kwargs.pop("timeout", None)
             can_read = await self.can_read(timeout)
             response = await self._reader.read(0) if can_read else None
         if isinstance(response, redis_async.ResponseError):
@@ -155,12 +162,9 @@ class FakeConnection(FakeBaseConnectionMixin, redis_async.Connection):
         return self._decode(response)
 
     def repr_pieces(self):
-        pieces = [
-            ('server', self._server),
-            ('db', self.db)
-        ]
+        pieces = [("server", self._server), ("db", self.db)]
         if self.client_name:
-            pieces.append(('client_name', self.client_name))
+            pieces.append(("client_name", self.client_name))
         return pieces
 
     def __str__(self):
@@ -230,10 +234,10 @@ class FakeRedis(redis_async.Redis):
         )
 
     @classmethod
-    def from_url(cls, url: str, **kwargs):
+    def from_url(cls, url: str, **kwargs) -> redis_async.Redis:
         self = super().from_url(url, **kwargs)
         pool = self.connection_pool  # Now override how it creates connections
         pool.connection_class = FakeConnection
-        pool.connection_kwargs.pop('username', None)
-        pool.connection_kwargs.pop('password', None)
+        pool.connection_kwargs.pop("username", None)
+        pool.connection_kwargs.pop("password", None)
         return self
